#!/bin/sh

# set & check where all the good stuff is
sbox=/scratchbox/users/$USER
utils=/scratchbox/tools/bin

# register arm binaries

sudo /scratchbox/sbin/register_arm

# do mount --bind:ing

if ! mount | grep -q " on $sbox/proc" ; then
	sudo mount --bind /proc $sbox/proc
fi
if ! mount | grep -q " on $sbox/tmp" ; then
	sudo mount --bind /tmp $sbox/tmp
fi
if ! mount | grep -q " on $sbox/scratchbox" ; then
	sudo mount --bind /scratchbox $sbox/scratchbox
fi
if [ -d /scratchbox_local/dev ]; then
	if ! mount | grep -q " on $sbox/scratchbox/dev" ; then
		sudo mount --bind /scratchbox_local/dev $sbox/scratchbox/dev
	fi
fi

if [ `id -u` == "0" ] ; then
	echo "Not allowed to run this as root! Use some normal user!"
	exit 1
fi

if [ ! -d "$sbox" ]; then
	echo "ERROR: Scratchbox dir '$sbox' is missing."
	exit 1
fi
if [ ! -d "$sbox/$utils" ]; then
	echo "ERROR: Scratchbox dir '$sbox/$utils' is missing."
	exit 1
fi
if [ ! -c "$sbox/dev/zero" ] ; then
	echo "ERROR: /dev is probably missing.!"
	exit 1
fi


# go to scratchbox
cd $sbox
if [ $? != 0 ]; then
	echo "ERROR: Could not change to '$sbox' directory."
 	exit 1
fi

# check shell
if [ ! -x "bin/sh" ]; then
	echo "ERROR: Sandbox shell '$sbox/$utils/sh' missing (Maybe sb mounts are not active?)."
	exit 1
fi

# check chroot-uid

if [ -f "/scratchbox_local/sbin/chroot-uid" ]; then
	CHROOT="/scratchbox_local/sbin/chroot-uid"
else
	CHROOT="/scratchbox/sbin/chroot-uid"
fi

if [ ! -f "$CHROOT" ]; then
	echo "ERROR: '$CHROOT' is missing."
	exit 1
fi
if [ ! -u "$CHROOT" ]; then
	echo "ERROR: '$CHROOT' is not suid ROOT."
	exit 1
fi
if [ ! -x "$CHROOT" ]; then
	echo "ERROR: You don't have permission to run '$CHROOT'."
	echo "Maybe you have not logged out and in again after being added to sbox group."
	exit 1
fi

# command to run services in chroot jail
RUN="sudo $CHROOT $PWD"

# rairai
if [ ! -f "$sbox/etc/nsswitch.conf" ] ; then
	cp /etc/nsswitch.conf "$sbox/etc/"
fi

if [ ! -f "$sbox/etc/resolv.conf" ] ; then
	cp /etc/resolv.conf "$sbox/etc/"
fi

if [ ! -f "$sbox/etc/passwd" ] ; then
	echo "root::0:0::/root:/bin/sh" > "$sbox/etc/passwd"
	echo "$USER::$UID:$GROUPS::$HOME:/bin/sh" >> "$sbox/etc/passwd"
fi

if [ ! -f "$sbox/etc/group" ] ; then
	echo "root:x:0:root" > "$sbox/etc/group"
	echo "`groups | cut -d ' ' -f 1`:x:$GROUPS:" >> "$sbox/etc/group"
	echo "sbox:x:`cat /etc/group | grep ^sbox: | cut -d ":" -f 3`:$USER" >> "$sbox/etc/group"
fi

if [ ! -d "$sbox/$HOME/.terminfo" ] ; then
	mkdir "$sbox/$HOME/.terminfo"
	cp -r /usr/share/terminfo/* "$sbox/$HOME/.terminfo/"
fi

# print sbox instructions
echo "
  Welcome to *Scratchbox*, the cross-compilation SDK!

Scratchbox is a self-contained mini-distribution that contains all the
tools needed to configure and cross-compile Open Source software using
GNU make and *autoconf*.  All the software configuration, compilation
and installation is done in a sandbox environment exactly like on your
target device.  This is achieved by using chroot or UML (User Mode
Linux) to limit system visibility for configuration scripts you run
from this shell, into what exists inside the scratchbox sandbox.

The Scrachbox utilities are:
  sbox-config -- Change your compilation target
  
"

# Select current target CPU
if [ ! -L "$sbox/targets/links/scratchbox.config" ]; then
	$RUN bin/sh -l $utils/sbox-config --create-target=PC --compiler-name=host-gcc
	$RUN bin/sh -l $utils/sbox-config --select-target=PC
fi

# Warn about missing target in .sbrsh
. $sbox/`ls -la $sbox/targets/links/scratchbox.config | cut -d / -f 8-`

SBRSH_TARGET=`cat /scratchbox/users/$USER/home/$USER/.sbrsh | grep "^$SBOX_TARGET_NAME[ \t]"`
if [ "x$SBRSH_TARGET" = "x" ] ; then
	if [ "$SBOX_CPU" != "i386" ] ; then
		echo
		echo "WARNING: You don't have this target in the"
		echo "/scratchbox/users/$USER/home/$USER/.sbrsh file."
		echo "This is needed by the cpuTransparency!"
		echo 
	fi
fi

#echo "---[ EXPORTING TARGET DIRECTORIES ]---"
#/scratchbox/sbin/sb-exportfs
#echo "--------------------------------------"

#  sbox-image -- Create target root image

# automatic scratchbox command execution
if [ ! -z $1 ]; then
	argc="-c $*"
else
	args=""
fi

# run SDK shell
$RUN bin/sh -l $args

# kill the script process group (everything run from this script)
kill -- -$$

